@@ -8,6 +8,7 @@ cookiecutter.prompt
 Functions for prompting the user for project info.
 """
 
+from __future__ import unicode_literals
 import sys
 
 PY3 = sys.version > '3'
@@ -17,25 +18,28 @@ else:
     input = raw_input
     iteritems = lambda d: d.iteritems()
 
+
 def prompt_for_config(context):
     """
     Prompts the user to enter new config, using context as a source for the
     field names and sample values.
     """
     cookiecutter_dict = {}
-    
+
     for key, val in iteritems(context['cookiecutter']):
         prompt = "{0} (default is \"{1}\")? ".format(key, val)
-        new_val = input(prompt)
+
+        if PY3:
+            new_val = input(prompt.encode('utf-8'))
+        else:
+            new_val = input(prompt.encode('utf-8')).decode('utf-8')
+
         new_val = new_val.strip()
 
         if new_val == '':
             new_val = val
-        
-        if PY3:
-            cookiecutter_dict[key] = new_val
-        else:
-            cookiecutter_dict[key] = new_val.decode('utf-8')
+
+        cookiecutter_dict[key] = new_val
     return cookiecutter_dict
 
 
