@@ -30,7 +30,7 @@ else:
 
 
 class TestPrompt(unittest.TestCase):
-    
+
     @patch(input_str, lambda x: 'Audrey Roy')
     def test_prompt_for_config_simple(self):
         context = {"cookiecutter": {"full_name": "Your Name"}}
@@ -55,6 +55,34 @@ class TestPrompt(unittest.TestCase):
         else:
             self.assertEqual(cookiecutter_dict, {"full_name": u"Pizzä ïs Gööd"})
 
+    @patch(input_str, lambda x: 'Pizzä ïs Gööd')
+    def test_unicode_prompt_for_config_unicode(self):
+        context = {"cookiecutter": {"full_name": u"Řekni či napiš své jméno"}}
+
+        if not PY3:
+            sys.stdin = StringIO("Pizzä ïs Gööd")
+
+        cookiecutter_dict = prompt.prompt_for_config(context)
+
+        if PY3:
+            self.assertEqual(cookiecutter_dict, {"full_name": "Pizzä ïs Gööd"})
+        else:
+            self.assertEqual(cookiecutter_dict, {"full_name": u"Pizzä ïs Gööd"})
+
+    @patch(input_str, lambda x: '\n')
+    def test_unicode_prompt_for_default_config_unicode(self):
+        context = {"cookiecutter": {"full_name": u"Řekni či napiš své jméno"}}
+
+        if not PY3:
+            sys.stdin = StringIO("\n")
+
+        cookiecutter_dict = prompt.prompt_for_config(context)
+
+        if PY3:
+            self.assertEqual(cookiecutter_dict, {"full_name": "Řekni či napiš své jméno"})
+        else:
+            self.assertEqual(cookiecutter_dict, {"full_name": u"Řekni či napiš své jméno"})
+
 
 class TestQueryAnswers(unittest.TestCase):
 
